@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
+Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
 
 The MySQL Connector/C++ is licensed under the terms of the GPLv2
 <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -123,6 +123,29 @@ struct CPPCONN_PUBLIC_FUNC NonScrollableException : public SQLException
 	NonScrollableException(const std::string& reason) : SQLException(reason, "", 0) {}
 };
 
+struct CPPCONN_PUBLIC_FUNC SQLUnsupportedOptionException : public SQLException
+{
+	SQLUnsupportedOptionException(const SQLUnsupportedOptionException& e, const std::string conn_option) :
+		SQLException(e.what(), e.sql_state, e.errNo),
+		option(conn_option )  
+	{}
+
+	SQLUnsupportedOptionException(const std::string& reason, const std::string conn_option) : 
+		SQLException(reason, "", 0),
+		option(conn_option )  
+	{}
+
+	const char *getConnectionOption() const
+	{
+		return option.c_str();
+	}
+
+	~SQLUnsupportedOptionException() throw () {};
+protected:
+	const std::string option;
+};
+
+
 } /* namespace sql */
 
 #endif /* _SQL_EXCEPTION_H_ */
