@@ -91,7 +91,7 @@ MySQL_Prepared_ResultSet::MySQL_Prepared_ResultSet(
             MySQL_Prepared_Statement * par,
             boost::shared_ptr< MySQL_DebugLogger > & l
         )
-    : row(NULL), proxy(s), last_queried_column(std::numeric_limits<uint32_t>::max()), row_position(0), parent(par),
+    : proxy(s), last_queried_column(std::numeric_limits<uint32_t>::max()), row_position(0), parent(par),
      is_valid(true), logger(l), result_bind(r_bind), resultset_type(rset_type)
 {
     CPP_ENTER("MySQL_Prepared_ResultSet::MySQL_Prepared_ResultSet");
@@ -449,7 +449,7 @@ MySQL_Prepared_ResultSet::getDouble(const uint32_t columnIndex) const
         case sql::DataType::JSON:
         {
             CPP_INFO("It's a string");
-            long double ret = sql::mysql::util::strtold(getString(columnIndex).c_str(), NULL);
+            long double ret = sql::mysql::util::strtonum(getString(columnIndex).c_str());
             CPP_INFO_FMT("value=%10.10f", ret);
             return ret;
         }
