@@ -368,7 +368,7 @@ MySQL_ResultSet::getDouble(const uint32_t columnIndex) const
     if (getFieldMeta(columnIndex)->type == MYSQL_TYPE_BIT) {
         return static_cast<long double>(getInt64(columnIndex));
     }
-    return sql::mysql::util::strtold(row[columnIndex - 1], NULL);
+    return sql::mysql::util::strtonum(row[columnIndex - 1]);
 }
 /* }}} */
 
@@ -893,18 +893,22 @@ MySQL_ResultSet::next()
             afterLast();
         } else if (row_position < num_rows + 1) {
             row = result->fetch_row();
-            boost::shared_ptr< NativeAPI::NativeConnectionWrapper > proxy_p = proxy.lock();
-            if (!proxy_p) {
-                throw sql::InvalidInstanceException("Connection has been closed");
-            }
 
-            if (row == NULL && (proxy_p->errNo() == 2013 ||
-                                proxy_p->errNo() == 2000)) {
+
+            if (row == NULL)
+            {
+              boost::shared_ptr< NativeAPI::NativeConnectionWrapper > proxy_p = proxy.lock();
+              if (!proxy_p) {
+                  throw sql::InvalidInstanceException("Connection has been closed");
+              }
+              if (proxy_p->errNo() == 2013 || proxy_p->errNo() == 2000)
+              {
                 CPP_ERR_FMT("Error fetching next row %d:(%s) %s",
                             proxy_p->errNo(), proxy_p->sqlstate().c_str(),
                             proxy_p->error().c_str());
                 sql::SQLException e(proxy_p->error(), proxy_p->sqlstate(), proxy_p->errNo());
                 throw e;
+              }
             }
             ++row_position;
             ret = (row != NULL);
@@ -913,18 +917,20 @@ MySQL_ResultSet::next()
         // reset last_queried_column
         last_queried_column = -1;
         row = result->fetch_row();
-        boost::shared_ptr< NativeAPI::NativeConnectionWrapper > proxy_p = proxy.lock();
-        if (!proxy_p) {
-            throw sql::InvalidInstanceException("Connection has been closed");
-        }
-
-        if (row == NULL && (proxy_p->errNo() == 2013 ||
-                            proxy_p->errNo() == 2000)) {
+        if (row == NULL)
+        {
+          boost::shared_ptr< NativeAPI::NativeConnectionWrapper > proxy_p = proxy.lock();
+          if (!proxy_p) {
+              throw sql::InvalidInstanceException("Connection has been closed");
+          }
+          if (proxy_p->errNo() == 2013 || proxy_p->errNo() == 2000)
+          {
             CPP_ERR_FMT("Error fetching next row %d:(%s) %s",
                         proxy_p->errNo(), proxy_p->sqlstate().c_str(),
                         proxy_p->error().c_str());
             sql::SQLException e(proxy_p->error(), proxy_p->sqlstate(), proxy_p->errNo());
             throw e;
+          }
         }
         if ((ret = (row != NULL))) {
             ++row_position;
