@@ -1,15 +1,30 @@
 /*
-   Copyright 2009 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 
+
+
 #include "libmysql_dynamic_proxy.h"
 
 #include <cppconn/exception.h>
@@ -68,7 +83,7 @@ LibmysqlDynamicProxy::LibmysqlDynamicProxy(const SQLString & dir2look, const SQL
 LibmysqlDynamicProxy::~LibmysqlDynamicProxy()
 {
     ptr2mysql_library_end endProc = symbol_safe_cast<ptr2mysql_library_end>(GetProcAddr("mysql_server_end"));
-	
+
 	if (endProc != NULL) {
 		(*endProc)();
 	}
@@ -81,7 +96,7 @@ void
 LibmysqlDynamicProxy::init_loader()
 {
 	ptr2mysql_library_init initProc = symbol_safe_cast<ptr2mysql_library_init>(GetProcAddr("mysql_server_init"));
-	
+
 	if (initProc != NULL) {
 		(*initProc)(0, NULL, NULL);
 	} else {
@@ -283,6 +298,28 @@ LibmysqlDynamicProxy::get_server_version(MYSQL * mysql)
 /* }}} */
 
 
+/* {{{ LibmysqlDynamicProxy::get_character_set_info() */
+void
+LibmysqlDynamicProxy::get_character_set_info(MYSQL * mysql, void *cs)
+{
+	ptr2mysql_get_character_set_info ptr2_get_character_set_info = symbol_safe_cast<ptr2mysql_get_character_set_info>(GetProcAddr("mysql_get_character_set_info"));
+
+	return (*ptr2_get_character_set_info)(mysql, static_cast<MY_CHARSET_INFO *>(cs));
+}
+/* }}} */
+
+
+/* {{{ LibmysqlDynamicProxy::info() */
+const char *
+LibmysqlDynamicProxy::info(MYSQL * mysql)
+{
+	ptr2mysql_info ptr2_info = symbol_safe_cast<ptr2mysql_info>(GetProcAddr("mysql_info"));
+
+	return (*ptr2_info)(mysql);
+}
+/* }}} */
+
+
 /* {{{ LibmysqlDynamicProxy::init() */
 MYSQL *
 LibmysqlDynamicProxy::init(MYSQL * mysql)
@@ -366,7 +403,47 @@ LibmysqlDynamicProxy::options(MYSQL * mysql, enum mysql_option option, const voi
 {
 	ptr2mysql_options ptr2_options = symbol_safe_cast<ptr2mysql_options>(GetProcAddr("mysql_options"));
 
-	return (*ptr2_options)(mysql, option, arg);
+	if ((*ptr2_options)(mysql, option, arg)) {
+		throw sql::InvalidArgumentException("Unsupported option provided to mysql_options()");
+	} else {
+		return 0;
+	}
+}
+/* }}} */
+
+
+/* {{{ LibmysqlDynamicProxy::options() */
+int
+LibmysqlDynamicProxy::options(MYSQL * mysql, enum mysql_option option, const void *arg1, const void *arg2)
+{
+	ptr2mysql_options4 ptr2_options = symbol_safe_cast<ptr2mysql_options4>(GetProcAddr("mysql_options4"));
+	if (ptr2_options != NULL) {
+		if (((*ptr2_options)(mysql, option, arg1, arg2))) {
+			throw sql::InvalidArgumentException("Unsupported option provided to mysql_options4()");
+		} else {
+			return 0;
+		}
+	} else {
+		throw ::sql::MethodNotImplementedException("::mysql_options4()");
+	}
+}
+/* }}} */
+
+
+/* {{{ LibmysqlDynamicProxy::get_option() */
+int
+LibmysqlDynamicProxy::get_option(MYSQL * mysql, enum mysql_option option, const void *arg)
+{
+	ptr2mysql_get_option ptr2_get_option = symbol_safe_cast<ptr2mysql_options4>(GetProcAddr("mysql_get_option"));
+	if (ptr2_get_option != NULL) {
+		if (((*ptr2_get_option)(mysql, option, arg))) {
+			throw sql::InvalidArgumentException("Unsupported option provided to mysql_get_option()");
+		} else {
+			return 0;
+		}
+	} else {
+		throw ::sql::MethodNotImplementedException("::mysql_get_option()");
+	}
 }
 /* }}} */
 
@@ -382,6 +459,17 @@ LibmysqlDynamicProxy::query(MYSQL * mysql, const char *stmt_str)
 /* }}} */
 
 
+/* {{{ LibmysqlDynamicProxy::ping() */
+int
+LibmysqlDynamicProxy::ping(MYSQL * mysql)
+{
+	ptr2mysql_ping ptr2_ping = symbol_safe_cast<ptr2mysql_ping>(GetProcAddr("mysql_ping"));
+
+	return (*ptr2_ping)(mysql);
+}
+/* }}} */
+
+
 /* {{{ LibmysqlDynamicProxy::real_connect() */
 MYSQL *
 LibmysqlDynamicProxy::real_connect(MYSQL * mysql,
@@ -401,6 +489,17 @@ LibmysqlDynamicProxy::real_connect(MYSQL * mysql,
 /* }}} */
 
 
+/* {{{ LibmysqlDynamicProxy::real_escape_string() */
+unsigned long
+LibmysqlDynamicProxy::real_escape_string(MYSQL * mysql, char * to, const char * from, unsigned long length)
+{
+	ptr2mysql_real_escape_string ptr2_realescapestring = symbol_safe_cast<ptr2mysql_real_escape_string>(GetProcAddr("mysql_real_escape_string"));
+
+	return (*ptr2_realescapestring)(mysql, to, from, length);
+}
+/* }}} */
+
+
 /* {{{ LibmysqlDynamicProxy::real_query() */
 int
 LibmysqlDynamicProxy::real_query(MYSQL *mysql,const char *stmt_str, unsigned long len)
@@ -472,6 +571,17 @@ LibmysqlDynamicProxy::use_result(MYSQL * mysql)
 /* }}} */
 
 
+/* {{{ LibmysqlDynamicProxy::warning_count() */
+unsigned int
+LibmysqlDynamicProxy::warning_count(MYSQL * mysql)
+{
+  ptr2mysql_warning_count ptr2_warning_count= symbol_safe_cast<ptr2mysql_warning_count>(GetProcAddr("mysql_warning_count"));
+
+	return (*ptr2_warning_count)(mysql);
+}
+/* }}} */
+
+
 /* Prepared Statement mysql_stmt_* functions */
 
 /* {{{ LibmysqlDynamicProxy::stmt_affected_rows() */
@@ -683,6 +793,53 @@ LibmysqlDynamicProxy::stmt_store_result(MYSQL_STMT * stmt)
 /* }}} */
 
 
+/* {{{ LibmysqlDynamicProxy::stmt_next_result() */
+int
+LibmysqlDynamicProxy::stmt_next_result(MYSQL_STMT * stmt)
+{
+	ptr2mysql_stmt_next_result ptr2_stmt_next_result = symbol_safe_cast<ptr2mysql_stmt_next_result>(GetProcAddr("mysql_stmt_next_result"));
+	if (ptr2_stmt_next_result != NULL) {
+		return (*ptr2_stmt_next_result)(stmt);
+	} else {
+		throw ::sql::MethodNotImplementedException("::mysql_stmt_next_result()");
+	}
+}
+/* }}} */
+
+
+/* {{{ LibmysqlDynamicProxy::stmt_free_result() */
+bool
+LibmysqlDynamicProxy::stmt_free_result(MYSQL_STMT * stmt)
+{
+        ptr2mysql_stmt_free_result ptr2_stmt_free_result = symbol_safe_cast<ptr2mysql_stmt_free_result>(GetProcAddr("mysql_stmt_free_result"));
+
+        return (*ptr2_stmt_next_result)(stmt);
+}
+/* }}} */
+
+
+/* {{{ LibmysqlDynamicProxy::thread_end() */
+void
+LibmysqlDynamicProxy::thread_end()
+{
+	ptr2mysql_thread_end ptr2_thread_end = symbol_safe_cast<ptr2mysql_thread_end>(GetProcAddr("mysql_thread_end"));
+
+	(*ptr2_thread_end)();
+}
+/* }}} */
+
+
+/* {{{ LibmysqlDynamicProxy::thread_init() */
+void
+LibmysqlDynamicProxy::thread_init()
+{
+	ptr2mysql_thread_init ptr2_thread_init = symbol_safe_cast<ptr2mysql_thread_init>(GetProcAddr("mysql_thread_init"));
+
+	(*ptr2_thread_init)();
+}
+/* }}} */
+
+
 } /* namespace util */
 } /* namespace mysql */
 } /* namespace sql */
