@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
+Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
 
 The MySQL Connector/C++ is licensed under the terms of the GPLv2
 <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -110,6 +110,8 @@ public:
 
 	unsigned long get_server_version(MYSQL * mysql);
 
+	void get_character_set_info(MYSQL * mysql, void *cs);
+
 	const char * info(MYSQL * mysql);
 
 	MYSQL * init(MYSQL * mysql);
@@ -128,6 +130,10 @@ public:
 
 	int options(MYSQL *, enum mysql_option, const void *);
 
+	int options(MYSQL *, enum mysql_option, const void *, const void *);
+
+	int get_option(MYSQL *, enum mysql_option, const void *);
+
 	int ping(MYSQL *);
 
 	int query(MYSQL *, const char *);
@@ -201,6 +207,10 @@ public:
 
 	int stmt_store_result(MYSQL_STMT *);
 
+	int stmt_next_result(MYSQL_STMT *);
+
+	bool stmt_free_result(MYSQL_STMT *);
+
 	void thread_init();
 
 	void thread_end();
