@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
+Copyright (c) 2008, 2017, Oracle and/or its affiliates. All rights reserved.
 
 The MySQL Connector/C++ is licensed under the terms of the GPLv2
 <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -44,10 +44,13 @@ with this program; if not, write to the Free Software Foundation, Inc.,
 #undef max
 #endif
 
-#if ( defined(_WIN32) || defined(_WIN64) ) && !defined(snprintf)
+#if ( defined(_WIN32) || defined(_WIN64) ) && !defined(snprintf) && (_MSC_VER < 1900)
 #define snprintf _snprintf
 #endif
 
+#if ( defined(_WIN32) || defined(_WIN64) ) && (_MSC_VER >= 1900)
+#define HAVE_STRUCT_TIMESPEC
+#endif
 
 #if !defined(_WIN32) && !defined(_WIN64)
 extern "C"
