@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
+Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
 
 The MySQL Connector/C++ is licensed under the terms of the GPLv2
 <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -97,6 +97,10 @@ public:
 
 	virtual int store_result() = 0;
 
+	virtual int stmt_next_result() = 0;
+
+	virtual bool stmt_free_result() = 0;
+
 	/* some enhancements comparing to mysql api */
 	virtual unsigned int warning_count() = 0;
 };
