@@ -1,14 +1,29 @@
 /*
-   Copyright 2007 - 2008 MySQL AB, 2008 - 2010 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
+
+
 /**
 * Types of execptions thrown by Connector/C++
 *
@@ -20,6 +35,8 @@
 #include <sstream>
 #include <stdexcept>
 
+#include <boost/scoped_ptr.hpp>
+
 /*
   Public interface of the MySQL Connector/C++.
   You might not use it but directly include directly the different
@@ -50,11 +67,11 @@ int main(int argc, const char **argv)
 	try {
 		/* Using the Driver to create a connection */
 		driver = sql::mysql::get_driver_instance();
-		std::auto_ptr< sql::Connection > con(driver->connect(host, user, pass));
+		boost::scoped_ptr< sql::Connection > con(driver->connect(host, user, pass));
 
 		/* Run in autocommit mode */
 		con->setAutoCommit(1);
-		std::auto_ptr< sql::Savepoint > savepoint(NULL);
+		boost::scoped_ptr< sql::Savepoint > savepoint(NULL);
 		try {
 			// It makes no sense to set a savepoint in autocommit mode
 			savepoint.reset(con->setSavepoint(string("before_insert")));
@@ -67,7 +84,7 @@ int main(int argc, const char **argv)
 
 		con->setSchema(database);
 
-		std::auto_ptr< sql::Statement > stmt(con->createStatement());
+		boost::scoped_ptr< sql::Statement > stmt(con->createStatement());
 		stmt->execute("DROP TABLE IF EXISTS test");
 		stmt->execute("CREATE TABLE test(id INT NOT NULL AUTO_INCREMENT PRIMARY KEY, label CHAR(1))");
 		cout << "#\t Test table created" << endl;
@@ -91,7 +108,7 @@ int main(int argc, const char **argv)
 		savepoint.reset(con->setSavepoint(string("before_insert")));
 
 		{
-			std::auto_ptr< sql::PreparedStatement > prep_stmt(con->prepareStatement("INSERT INTO test(id, label) VALUES (?, ?)"));
+			boost::scoped_ptr< sql::PreparedStatement > prep_stmt(con->prepareStatement("INSERT INTO test(id, label) VALUES (?, ?)"));
 			for (i = 0; i < EXAMPLE_NUM_TEST_ROWS; i++) {
 				prep_stmt->setInt(1, test_data[i].id);
 				prep_stmt->setString(2, test_data[i].label);
@@ -100,7 +117,7 @@ int main(int argc, const char **argv)
 		}
 
 		try {
-			std::auto_ptr< sql::PreparedStatement > prep_stmt(con->prepareStatement("INSERT INTO test(id, label) VALUES (?, ?)"));
+			boost::scoped_ptr< sql::PreparedStatement > prep_stmt(con->prepareStatement("INSERT INTO test(id, label) VALUES (?, ?)"));
 			prep_stmt->setInt(1, test_data[0].id);
 			/* This will cause a duplicate index error */
 			prep_stmt->executeUpdate();
@@ -137,7 +154,7 @@ int main(int argc, const char **argv)
 		*/
 		cout << endl;
 		cout << "# ERR: DbcException in " << __FILE__;
-		cout << "(" << __FUNCTION__ << ") on line " << __LINE__ << endl;
+		cout << "(" << EXAMPLE_FUNCTION << ") on line " << __LINE__ << endl;
 		/* Use what(), getErrorCode() and getSQLState() */
 		cout << "# ERR: " << e.what();
 		cout << " (MySQL error code: " << e.getErrorCode();
@@ -157,7 +174,7 @@ int main(int argc, const char **argv)
 
 		cout << endl;
 		cout << "# ERR: runtime_error in " << __FILE__;
-		cout << "(" << __FUNCTION__ << ") on line " << __LINE__ << endl;
+		cout << "(" << EXAMPLE_FUNCTION << ") on line " << __LINE__ << endl;
 		cout << "# ERR: " << e.what() << endl;
 		cout << "not ok 1 - examples/exceptions.cpp" << endl;
 
