@@ -1,13 +1,28 @@
 /*
-   Copyright 2008 - 2009 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
+
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
+*/
+
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
- */
 
 #include <stdio.h>
 
@@ -171,8 +186,8 @@ void TestsListener::testHasFinished(TestRunResult result, const String & msg)
 
     clock_t time=Timer::stopTest(testFullName());
     float total = Timer::translate2seconds(time);
-    
-    static std::stringstream tmp;    
+
+    static std::stringstream tmp;
 
     tmp.precision(10);
     tmp.str("");
@@ -188,7 +203,7 @@ void TestsListener::testHasFinished(TestRunResult result, const String & msg)
       time=Timer::getTime(*it);
       tmp << "#   " << std::setw(38) << std::left << *it;
       tmp << " = " << std::setw(13) << std::right << Timer::translate2seconds(time) << "s";
-      
+
       tmp << " (";
       tmp << std::setw(6) << std::right;
       if (total > 0.0) {
@@ -199,7 +214,7 @@ void TestsListener::testHasFinished(TestRunResult result, const String & msg)
         tmp << "n/a ";
       }
       tmp << "%)";
-      
+
       tmp << " (line " << Timer::getLine(*it) << ")" << std::endl;
     }
 
@@ -258,7 +273,7 @@ void TestsListener::summary()
 
 bool TestsListener::allTestsPassed()
 {
-  return theInstance().exceptions && !theInstance().failed() == 0;
+  return theInstance().exceptions && !(theInstance().failed() == 0);
 }
 
 void TestsListener::bailSuite(const String & reason)
