@@ -66,6 +66,10 @@ public:
     TEST_CASE(bug21053335);
     TEST_CASE(bug21067193);
     TEST_CASE(bug21066575);
+    TEST_CASE(bug21152054);
+    TEST_CASE(bug22292073);
+    TEST_CASE(bug23212333);
+    TEST_CASE(bug17227390);
   }
 
   /**
@@ -119,6 +123,14 @@ public:
 
   void bug21067193();
 
+  void bug21152054();
+
+  void bug22292073();
+
+  void bug23212333();
+
+  void bug17227390();
+
 };
 
 REGISTER_FIXTURE(bugs);
