@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
+Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
 
 The MySQL Connector/C++ is licensed under the terms of the GPLv2
 <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -96,6 +96,11 @@ public:
      */
     TEST_CASE(getColumnsTypeConversions);
 	TEST_CASE(bestIdUniqueNotNull);
+	TEST_CASE(getSchemaCollation);
+	TEST_CASE(getSchemaCharset);
+	TEST_CASE(getTableCollation);
+	TEST_CASE(getTableCharset);
+	TEST_CASE(getTables);
   }
 
   /**
@@ -356,6 +361,31 @@ public:
 
   void bestIdUniqueNotNull();
 
+  /**
+   * Test for DatabaseMetaData::getSchemaCollation()
+   */
+  void getSchemaCollation();
+
+  /**
+   * Test for DatabaseMetaData::getSchemaCharset()
+   */
+  void getSchemaCharset();
+
+  /**
+   * Test for DatabaseMetaData::getTableCollation()
+   */
+  void getTableCollation();
+
+  /**
+   * Test for DatabaseMetaData::getTableCharset()
+   */
+  void getTableCharset();
+
+  /**
+   * Test for DatabaseMetaData::getTables()
+   */
+  void getTables();
+
 };
 
 REGISTER_FIXTURE(connectionmetadata);
