@@ -1,13 +1,28 @@
 /*
-   Copyright 2008 - 2010 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
+
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
+*/
+
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
- */
 
 #include "example.h"
 
@@ -63,17 +78,17 @@ void example_test_class::test_hello_world2()
     /*
      Connection, Statement and ResultSet are typedefs from unit_fixture.h:
 
-     typedef std::auto_ptr<sql::Connection> Connection;
-     typedef std::auto_ptr<sql::PreparedStatement> PreparedStatement;
-     typedef std::auto_ptr<sql::ParameterMetaData> ParameterMetaData;
-     typedef std::auto_ptr<sql::Statement> Statement;
-     typedef std::auto_ptr<sql::Savepoint> Savepoint;
-     typedef std::auto_ptr<sql::ResultSet> ResultSet;
+     typedef boost::scoped_ptr<sql::Connection> Connection;
+     typedef boost::scoped_ptr<sql::PreparedStatement> PreparedStatement;
+     typedef boost::scoped_ptr<sql::ParameterMetaData> ParameterMetaData;
+     typedef boost::scoped_ptr<sql::Statement> Statement;
+     typedef boost::scoped_ptr<sql::Savepoint> Savepoint;
+     typedef boost::scoped_ptr<sql::ResultSet> ResultSet;
      typedef sql::Driver Driver;
-     typedef std::auto_ptr<sql::ResultSetMetaData> ResultSetMetaData;
-     typedef std::auto_ptr<sql::DatabaseMetaData> DatabaseMetaData;
+     typedef boost::scoped_ptr<sql::ResultSetMetaData> ResultSetMetaData;
+     typedef boost::scoped_ptr<sql::DatabaseMetaData> DatabaseMetaData;
 
-     Do yourself a favour and use auto_ptr in tests!
+     Do yourself a favour and use boost::scoped_ptr in tests!
      */
     Connection my_con(getConnection());
     Statement my_stmt(my_con->createStatement());
