@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
+Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
 
 The MySQL Connector/C++ is licensed under the terms of the GPLv2
 <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -97,9 +97,9 @@ void unit_fixture::init()
   columns.push_back(columndefinition("BIGINT", "BIGINT", sql::DataType::BIGINT, "-9223372036854775808", true, 19, 0, true, "", 0, "NO", true, "-9223372036854775808"));
 
   columns.push_back(columndefinition("BIGINT", "BIGINT NOT NULL", sql::DataType::BIGINT, "-9223372036854775808", true, 19, 0, false, "", 0, "NO", true));
-  columns.push_back(columndefinition("BIGINT UNSIGNED", "BIGINT UNSIGNED", sql::DataType::BIGINT, "18446744073709551615", false, 19, 0, true, "", 0, "NO", false, "18446744073709551615"));
-  columns.push_back(columndefinition("BIGINT UNSIGNED", "BIGINT UNSIGNED", sql::DataType::BIGINT, "18446744073709551615", false, 19, 0, true, "", 0, "NO", false));
-  columns.push_back(columndefinition("BIGINT UNSIGNED ZEROFILL", "BIGINT(4) ZEROFILL DEFAULT 10101", sql::DataType::BIGINT, "2", false, 19, 0, true, "10101", 0, "NO", false));
+  columns.push_back(columndefinition("BIGINT UNSIGNED", "BIGINT UNSIGNED", sql::DataType::BIGINT, "18446744073709551615", false, 20, 0, true, "", 0, "NO", false, "18446744073709551615"));
+  columns.push_back(columndefinition("BIGINT UNSIGNED", "BIGINT UNSIGNED", sql::DataType::BIGINT, "18446744073709551615", false, 20, 0, true, "", 0, "NO", false));
+  columns.push_back(columndefinition("BIGINT UNSIGNED ZEROFILL", "BIGINT(4) ZEROFILL DEFAULT 10101", sql::DataType::BIGINT, "2", false, 20, 0, true, "10101", 0, "NO", false));
   columns.push_back(columndefinition("FLOAT", "FLOAT", sql::DataType::REAL, "-1.01", true, 12, 0, true, "", 0, "NO", true));
   columns.push_back(columndefinition("FLOAT", "FLOAT NOT NULL", sql::DataType::REAL, "-1.01", true, 12, 0, false, "", 0, "NO", true));
   columns.push_back(columndefinition("FLOAT UNSIGNED", "FLOAT UNSIGNED", sql::DataType::REAL, "1.01", false, 12, 0, true, "", 0, "NO", false));
@@ -132,7 +132,7 @@ void unit_fixture::init()
   columns.push_back(columndefinition("YEAR", "YEAR NOT NULL", sql::DataType::YEAR, "1902", false, 4, 0, false, "", 0, "NO", false));
   columns.push_back(columndefinition("YEAR", "YEAR(4)", sql::DataType::YEAR, "2009", false, 4, 0, true, "", 0, "NO", false, "2009"));
 
-  columns.push_back(columndefinition("YEAR", "YEAR(2)", sql::DataType::YEAR, "1", false, 2, 0, true, "", 0, "NO", false));
+  columns.push_back(columndefinition("YEAR", "YEAR(2)", sql::DataType::YEAR, "1", false, 4, 0, true, "", 0, "NO", false));
   columns.push_back(columndefinition("YEAR", "YEAR(3) DEFAULT '2009'", sql::DataType::YEAR, "1", false, 4, 0, true, "2009", 0, "NO", false));
 
   columns.push_back(columndefinition("CHAR", "CHAR", sql::DataType::CHAR, "a", true, 1, 0, true, "", 0, "NO", false, "a"));
@@ -325,8 +325,7 @@ void unit_fixture::createSchemaObject(String object_type, String object_name,
   dropSchemaObject(object_type, object_name);
 
   String sql("CREATE  ");
-  sql.resize(object_name.length()
-             + object_type.length() + columns_and_other_stuff.length() + 10);
+
   sql.append(object_type);
   sql.append(" ");
   sql.append(object_name);
@@ -347,12 +346,15 @@ void unit_fixture::createTable(String table_name, String columns_and_other_stuff
   createSchemaObject("TABLE", table_name, columns_and_other_stuff);
 }
 
+
 void unit_fixture::dropTable(String table_name)
 {
   dropSchemaObject("TABLE", table_name);
 }
 
-sql::Connection * unit_fixture::getConnection()
+
+sql::Connection *
+unit_fixture::getConnection(sql::ConnectOptionsMap *additional_options)
 {
   if (driver == NULL)
   {
@@ -375,6 +377,15 @@ sql::Connection * unit_fixture::getConnection()
     logMsg("Connection using dynamic load of clientlib " DYNLOAD_MYSQL_LIB);
   }
 
+  if (additional_options != NULL)
+  {
+    for (sql::ConnectOptionsMap::const_iterator cit= additional_options->begin();
+         cit != additional_options->end(); ++cit)
+    {
+      connection_properties[cit->first]= cit->second;
+    }
+  }
+
   return driver->connect(connection_properties);
 }
 
@@ -388,11 +399,14 @@ void unit_fixture::logErr(const String & message)
   TestsListener::errorsLog(message + "\n");
 }
 
+
 void unit_fixture::logDebug(const String & message)
 {
   logMsg(message);
 }
 
+
+/* There is not really need to have it as a class method */
 int unit_fixture::getMySQLVersion(Connection & con)
 {
   DatabaseMetaData * dbmeta=con->getMetaData();
